/* Import this if you are using modernizr (recommended) 
It means that loaders will fallback to a text state of simply saying "Loading..." in older browsers
*/
.no-cssanimations .load-container .loader {
  text-indent: 0;
  text-align: center;
  color: #FFF;
  font-size: 17px;
  background: none;
  border: 0 none;
  width: auto;
  height: auto;
  margin: 1em auto;
  overflow: visible;
  box-shadow: none;
  -webkit-animation: none;
  animation: none;
}
.no-cssanimations .load-container .loader:before,
.no-cssanimations .load-container .loader:after {
  display: none;
}
