.shiny-spinner-output-container {
  position: relative;
}

.load-container {
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%);
  /* to avoid showing a vertical scrollbar
  http://stackoverflow.com/questions/38251204/horizontal-animation-causes-vertical-scrollbar-in-css */
  overflow:hidden; 
  width: 100%;
}

.shiny-spinner-hidden {
  position: absolute;
  top:0;
  left:0;
  z-index: -1;
  visibility:hidden;
}